@@ -5,17 +5,17 @@
 
     Command line interface.
 
-    :copyright: 2006-2007 by Georg Brandl.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2013 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 import sys
 import getopt
 from textwrap import dedent
 
-from pygments import __version__, __author__, highlight
+from pygments import __version__, highlight
 from pygments.util import ClassNotFound, OptionError, docstring_headline
 from pygments.lexers import get_all_lexers, get_lexer_by_name, get_lexer_for_filename, \
-     find_lexer_class
+     find_lexer_class, guess_lexer, TextLexer
 from pygments.formatters import get_all_formatters, get_formatter_by_name, \
      get_formatter_for_filename, find_formatter_class, \
      TerminalFormatter  # pylint:disable-msg=E0611
@@ -24,11 +24,12 @@ from pygments.styles import get_all_styles, get_style_by_name
 
 
 USAGE = """\
-Usage: %s [-l <lexer>] [-F <filter>[:<options>]] [-f <formatter>]
+Usage: %s [-l <lexer> | -g] [-F <filter>[:<options>]] [-f <formatter>]
           [-O <options>] [-P <option=value>] [-o <outfile>] [<infile>]
 
        %s -S <style> -f <formatter> [-a <arg>] [-O <options>] [-P <option=value>]
        %s -L [<which> ...]
+       %s -N <filename>
        %s -H <type> <name>
        %s -h | -V
 
@@ -38,7 +39,9 @@ If no input file is given, use stdin, if -o is not given, use stdout.
 
 <lexer> is a lexer name (query all lexer names with -L). If -l is not
 given, the lexer is guessed from the extension of the input file name
-(this obviously doesn't work if the input is stdin).
+(this obviously doesn't work if the input is stdin).  If -g is passed,
+attempt to guess the lexer from the file contents, or pass through as
+plain text if this fails (this can work for stdin).
 
 Likewise, <formatter> is a formatter name, and will be guessed from
 the extension of the output file name. If no output file is given,
@@ -66,6 +69,10 @@ The -L option lists lexers, formatters, styles or filters -- set
 `which` to the thing you want to list (e.g. "styles"), or omit it to
 list everything.
 
+The -N option guesses and prints out a lexer name based solely on
+the given filename. It does not take input or highlight anything.
+If no specific lexer can be determined "text" is returned.
+
 The -H option prints detailed help for the object <name> of type <type>,
 where <type> is one of "lexer", "formatter" or "filter".
 
@@ -183,10 +190,18 @@ def main(args=sys.argv):
     """
     # pylint: disable-msg=R0911,R0912,R0915
 
-    usage = USAGE % ((args[0],) * 5)
+    usage = USAGE % ((args[0],) * 6)
+
+    if sys.platform in ['win32', 'cygwin']:
+        try:
+            # Provide coloring under Windows, if possible
+            import colorama
+            colorama.init()
+        except ImportError:
+            pass
 
     try:
-        popts, args = getopt.getopt(args[1:], "l:f:F:o:O:P:LS:a:hVH")
+        popts, args = getopt.getopt(args[1:], "l:f:F:o:O:P:LS:a:N:hVHg")
     except getopt.GetoptError, err:
         print >>sys.stderr, usage
         return 2
@@ -212,7 +227,7 @@ def main(args=sys.argv):
         return 0
 
     if opts.pop('-V', None) is not None:
-        print 'Pygments version %s, (c) 2006-2007 by %s.' % (__version__, __author__)
+        print 'Pygments version %s, (c) 2006-2013 by Georg Brandl.' % __version__
         return 0
 
     # handle ``pygmentize -L``
@@ -259,6 +274,20 @@ def main(args=sys.argv):
             parsed_opts[name] = value
     opts.pop('-P', None)
 
+    # handle ``pygmentize -N``
+    infn = opts.pop('-N', None)
+    if infn is not None:
+        try:
+            lexer = get_lexer_for_filename(infn, **parsed_opts)
+        except ClassNotFound, err:
+            lexer = TextLexer()
+        except OptionError, err:
+            print >>sys.stderr, 'Error:', err
+            return 1
+
+        print lexer.aliases[0]
+        return 0
+
     # handle ``pygmentize -S``
     S_opt = opts.pop('-S', None)
     a_opt = opts.pop('-a', None)
@@ -279,7 +308,11 @@ def main(args=sys.argv):
             return 1
 
         arg = a_opt or ''
-        print fmter.get_style_defs(arg)
+        try:
+            print fmter.get_style_defs(arg)
+        except Exception, err:
+            print >>sys.stderr, 'Error:', err
+            return 1
         return 0
 
     # if no -S is given, -a is not allowed
@@ -309,7 +342,7 @@ def main(args=sys.argv):
                 print >>sys.stderr, 'Error:', err
                 return 1
         try:
-            outfile = file(outfn, 'wb')
+            outfile = open(outfn, 'wb')
         except Exception, err:
             print >>sys.stderr, 'Error: cannot open outfile:', err
             return 1
@@ -333,23 +366,41 @@ def main(args=sys.argv):
             return 2
 
         infn = args[0]
-        if not lexer:
-            try:
-                lexer = get_lexer_for_filename(infn, **parsed_opts)
-            except (OptionError, ClassNotFound), err:
-                print >>sys.stderr, 'Error:', err
-                return 1
-
         try:
-            code = file(infn).read()
+            code = open(infn, 'rb').read()
         except Exception, err:
             print >>sys.stderr, 'Error: cannot read infile:', err
             return 1
-    else:
+
         if not lexer:
-            print >>sys.stderr, 'Error: no lexer name given and reading from stdin'
+            try:
+                lexer = get_lexer_for_filename(infn, code, **parsed_opts)
+            except ClassNotFound, err:
+                if '-g' in opts:
+                    try:
+                        lexer = guess_lexer(code, **parsed_opts)
+                    except ClassNotFound:
+                        lexer = TextLexer(**parsed_opts)
+                else:
+                    print >>sys.stderr, 'Error:', err
+                    return 1
+            except OptionError, err:
+                print >>sys.stderr, 'Error:', err
+                return 1
+
+    else:
+        if '-g' in opts:
+            code = sys.stdin.read()
+            try:
+                lexer = guess_lexer(code, **parsed_opts)
+            except ClassNotFound:
+                lexer = TextLexer(**parsed_opts)
+        elif not lexer:
+            print >>sys.stderr, 'Error: no lexer name given and reading ' + \
+                                'from stdin (try using -g or -l <lexer>)'
             return 2
-        code = sys.stdin.read()
+        else:
+            code = sys.stdin.read()
 
     # No encoding given? Use latin1 if output file given,
     # stdin/stdout encoding otherwise.
@@ -359,9 +410,15 @@ def main(args=sys.argv):
             # encoding pass-through
             fmter.encoding = 'latin1'
         else:
-            # use terminal encoding
-            lexer.encoding = getattr(sys.stdin, 'encoding', None) or 'ascii'
-            fmter.encoding = getattr(sys.stdout, 'encoding', None) or 'ascii'
+            if sys.version_info < (3,):
+                # use terminal encoding; Python 3's terminals already do that
+                lexer.encoding = getattr(sys.stdin, 'encoding',
+                                         None) or 'ascii'
+                fmter.encoding = getattr(sys.stdout, 'encoding',
+                                         None) or 'ascii'
+    elif not outfn and sys.version_info > (3,):
+        # output to terminal with encoding -> use .buffer
+        outfile = sys.stdout.buffer
 
     # ... and do it!
     try:
