@@ -8,7 +8,7 @@
     style classes meant for putting into modules.
 
     :copyright 2006 by Armin Ronacher.
-    :license: BSD, see LICENSE for more details.
+    :license: BSD, see LICENSE for details.
 """
 
 import sys
@@ -885,10 +885,10 @@ class StyleWriter(object):
         if bg_color:
             out.write('    background_color = %r\n' % bg_color[0])
         out.write('    styles = {\n')
-        out.write('        %-20s%r\n' % ('Token:', default_token))
+        out.write('        %-20s%r,\n' % ('Token:', default_token))
         for token, definition in tokens:
             if definition:
-                out.write('        %-20s%r\n' % (token + ':', definition))
+                out.write('        %-20s%r,\n' % (token + ':', definition))
         out.write('    }')
 
     def __repr__(self):
