@@ -3,13 +3,11 @@
     Test suite for the token module
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2012 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2013 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import unittest
-import StringIO
-import sys
 
 from pygments import token
 
@@ -17,8 +15,7 @@ from pygments import token
 class TokenTest(unittest.TestCase):
 
     def test_tokentype(self):
-        e = self.assertEquals
-        r = self.assertRaises
+        e = self.assertEqual
 
         t = token.String
 
@@ -27,13 +24,13 @@ class TokenTest(unittest.TestCase):
         e(t.__class__, token._TokenType)
 
     def test_functions(self):
-        self.assert_(token.is_token_subtype(token.String, token.String))
-        self.assert_(token.is_token_subtype(token.String, token.Literal))
-        self.failIf(token.is_token_subtype(token.Literal, token.String))
+        self.assertTrue(token.is_token_subtype(token.String, token.String))
+        self.assertTrue(token.is_token_subtype(token.String, token.Literal))
+        self.assertFalse(token.is_token_subtype(token.Literal, token.String))
 
-        self.assert_(token.string_to_tokentype(token.String) is token.String)
-        self.assert_(token.string_to_tokentype('') is token.Token)
-        self.assert_(token.string_to_tokentype('String') is token.String)
+        self.assertTrue(token.string_to_tokentype(token.String) is token.String)
+        self.assertTrue(token.string_to_tokentype('') is token.Token)
+        self.assertTrue(token.string_to_tokentype('String') is token.String)
 
     def test_sanity_check(self):
         stp = token.STANDARD_TYPES.copy()
